Module: BigbluebuttonRails

Defined in:
lib/bigbluebutton_rails.rb,
lib/bigbluebutton_rails/rails.rb,
lib/bigbluebutton_rails/utils.rb,
lib/bigbluebutton_rails/version.rb,
lib/bigbluebutton_rails/exceptions.rb,
lib/bigbluebutton_rails/controller_methods.rb,
lib/generators/bigbluebutton_rails/views_generator.rb,
lib/bigbluebutton_rails/internal_controller_methods.rb,
lib/generators/bigbluebutton_rails/install_generator.rb

Defined Under Namespace

Modules: ControllerMethods, Generators, InternalControllerMethods Classes: Engine, RoomAccessDenied, ServerRequired

Constant Summary collapse

VERSION =
"1.4.0".freeze
@@controllers =
{
  :servers => 'bigbluebutton/servers',
  :rooms => 'bigbluebutton/rooms',
  :recordings => 'bigbluebutton/recordings'
}
@@routing_scope =
'bigbluebutton'
@@metadata_room_id =
:'bbbrails-room-id'
@@metadata_user_id =
:'bbbrails-user-id'
@@metadata_user_name =
:'bbbrails-user-name'
@@metadata_invalid_keys =
[ @@metadata_room_id,
@@metadata_user_id,
@@metadata_user_name ]
@@user_attr_name =
:'name'
@@user_attr_id =
:'id'

Class Method Summary collapse

Class Method Details

.match_room_recording(data) ⇒ Object

Finds the BigbluebuttonRoom associated with the recording data in ‘data’, if any. TODO: if not found, remove the association or keep the old one?



66
67
68
69
70
71
72
# File 'lib/bigbluebutton_rails.rb', line 66

def self.match_room_recording(data)
  if block_given?
    yield
  else
    BigbluebuttonRoom.find_by_meetingid(data[:meetingid])
  end
end

.set_controllers(options) ⇒ Object



74
75
76
77
78
# File 'lib/bigbluebutton_rails.rb', line 74

def self.set_controllers(options)
  unless options.nil?
    @@controllers.merge!(options).slice!(:servers, :rooms, :recordings)
  end
end

.setup {|_self| ... } ⇒ Object

Default way to setup the gem.

Yields:

  • (_self)

Yield Parameters:



81
82
83
# File 'lib/bigbluebutton_rails.rb', line 81

def self.setup
  yield self
end

.value_to_boolean(value) ⇒ Object

just a wrapper around the Rails method to convert values to boolean



4
5
6
# File 'lib/bigbluebutton_rails/utils.rb', line 4

def self.value_to_boolean(value)
  ActiveRecord::ConnectionAdapters::Column.value_to_boolean(value)
end